# constellaXion CLI

The fastest way to Train, Deploy and Serve Open Source Language Models to your Cloud environment

## Installation

Install the package:

```sh
pip install constellaxion
```


## Usage
1. Init your model:

    ```sh
    constellaXion init
    ```

2. View Training and Serving configurations:

    ```sh
    constallaXion model view
    ```

3. Run training job:

    ```sh
    constallaXion model train
    ```

4. Serve model:

    ```sh
    constallaXion model serve
    ```

5. Prompt model:

    ```sh
    constallaXion model prompt
    ```
